@@ -211,7 +211,7 @@ class API(Interface):
 
         try:
             json.dumps([value])
-        except ValueError as e:
+        except ValueError as e:  # pragma: no cover
             raise TypeError("设置常量的类型必须是可被json序列化的对象") from e
 
         set_const(self.qid, name, value)
@@ -253,7 +253,7 @@ class API(Interface):
             " - API说明文档 - 目录 - \n" + "\n".join(content),
             *description,
         ]
-        return await self.send_fwd(msgs)
+        return await self.feedback(msgs, fwd=True)
 
     @export
     @descript(
