@@ -3,12 +3,12 @@ from pathlib import Path
 from typing import Any
 
 from nonebot_plugin_alconna.uniseg import At, Image, Reply, Text, UniMessage
-from nonebot_plugin_localstore import get_plugin_data_dir
+from nonebot_plugin_localstore import get_data_dir
 
 from ..constant import T_ConstVar, T_Context, T_OptConstVar
 
 default_context: T_Context = {}
-
+DATA_DIR = get_data_dir("nonebot_plugin_exe_code")
 
 def context_var(item: Any, name: str | None = None) -> None:
     key = name or getattr(item, "__name__", None)
@@ -23,7 +23,7 @@ context_var(lambda x: Reply(id=str(x)), "Reply")
 
 
 def _const_var_path(uin: str) -> Path:
-    fp = get_plugin_data_dir() / f"{uin}.json"
+    fp = DATA_DIR / f"{uin}.json"
     if not fp.exists():
         fp.write_text("{}")
     return fp
