@@ -1,12 +1,12 @@
 import asyncio
 import functools
-import inspect
-from collections.abc import Awaitable, Callable, Coroutine, Iterable
-from typing import Any, ClassVar, Self, cast, overload
-from typing_extensions import TypeIs
+from collections.abc import Callable, Coroutine, Iterable
+from typing import Any, ClassVar, Generic, ParamSpec, TypeVar, cast, overload
+from typing_extensions import Self, TypeIs
 
 from nonebot.adapters import Bot, Message, MessageSegment
 from nonebot.log import logger
+from nonebot.utils import is_coroutine_callable
 from nonebot_plugin_alconna.uniseg import (
     CustomNode,
     Receipt,
@@ -31,49 +31,51 @@ WRAPPER_ASSIGNMENTS = (
     INTERFACE_METHOD_DESCRIPTION,
 )
 
+P = ParamSpec("P")
+R = TypeVar("R")
+T = TypeVar("T")
 
-def export[**P, R](call: Callable[P, R]) -> Callable[P, R]:
+
+def export(call: Callable[P, R]) -> Callable[P, R]:
     """将一个方法标记为导出函数"""
     setattr(call, INTERFACE_EXPORT_METHOD, True)
     return call
 
 
-type Coro[T] = Coroutine[None, None, T]
-
-
-def is_coroutine_callable(call: Callable[..., Any]) -> TypeIs[Callable[..., Coro[Any]]]:
-    """检查 call 是否是一个 callable 协程函数"""
-    if inspect.isroutine(call):
-        return inspect.iscoroutinefunction(call)
-    if inspect.isclass(call):
-        return False
-    func = getattr(call, "__call__", None)
-    return inspect.iscoroutinefunction(func)
+class Coro(Coroutine[None, None, T], Generic[T]): ...
 
 
 @overload
-def debug_log[**P, R](call: Callable[P, Coro[R]]) -> Callable[P, Coro[R]]: ...
+def debug_log(call: Callable[P, Coro[R]]) -> Callable[P, Coro[R]]: ...
 
 
 @overload
-def debug_log[**P, R](call: Callable[P, R]) -> Callable[P, R]: ...
+def debug_log(call: Callable[P, R]) -> Callable[P, R]: ...
 
 
-def debug_log[**P, R](call: Callable[P, Coro[R] | R]) -> Callable[P, Coro[R] | R]:
+def debug_log(
+    call: Callable[P, Coro[R]] | Callable[P, R]
+) -> Callable[P, Coro[R]] | Callable[P, R]:
     if is_coroutine_callable(call):
-        # 本来应该用 # pyright: ignore[reportRedeclaration]
-        # 但是格式化后有点难绷，所以直接用了 # type: ignore
-        async def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:  # type: ignore
+        call = cast(Callable[P, Coro[R]], call)
+
+        async def wrapper(  # pyright: ignore[reportRedeclaration]
+            *args: P.args, **kwargs: P.kwargs
+        ) -> R:
             logger.debug(f"{call.__name__}: args={args}, kwargs={kwargs}")
-            return await cast(Callable[P, Coro[R]], call)(*args, **kwargs)
+            return await call(*args, **kwargs)
 
     else:
+        call = cast(Callable[P, R], call)
 
         def wrapper(*args: P.args, **kwargs: P.kwargs) -> R:
             logger.debug(f"{call.__name__}: args={args}, kwargs={kwargs}")
-            return cast(Callable[P, R], call)(*args, **kwargs)
+            return call(*args, **kwargs)
 
-    return functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS)
+    return cast(
+        Callable[P, Coro[R]] | Callable[P, R],
+        functools.update_wrapper(wrapper, call, assigned=WRAPPER_ASSIGNMENTS),
+    )
 
 
 def is_export_method(call: Callable[..., Any]) -> bool:
@@ -163,11 +165,11 @@ def _send_message(limit: int):
         if key in call_cnt:
             del call_cnt[key]
 
-    def send_message(
+    async def send_message(
         session: Session,
         target: Target | None,
         message: T_Message,
-    ) -> Awaitable[Receipt]:
+    ) -> Receipt:
         key = id(session)
         if key not in call_cnt:
             call_cnt[key] = 1
@@ -178,11 +180,8 @@ def _send_message(limit: int):
         else:
             call_cnt[key] += 1
 
-        async def send_message_inner():
-            msg = await as_unimsg(message)
-            return await msg.send(target)
-
-        return asyncio.create_task(send_message_inner())
+        msg = await as_unimsg(message)
+        return await msg.send(target)
 
     return send_message
 
@@ -190,11 +189,11 @@ def _send_message(limit: int):
 send_message = _send_message(limit=6)
 
 
-def send_forward_message(
+async def send_forward_message(
     session: Session,
     target: Target | None,
     msgs: Iterable[T_Message],
-) -> Awaitable[Receipt]:
+) -> Receipt:
     async def create_node(msg: T_Message) -> CustomNode:
         return CustomNode(
             uid="0",
@@ -202,15 +201,12 @@ def send_forward_message(
             content=await as_unimsg(msg),
         )
 
-    async def send_forward_inner():
-        nodes = await asyncio.gather(*[create_node(msg) for msg in msgs])
-        return await send_message(
-            session=session,
-            target=target,
-            message=Reference(nodes=nodes),
-        )
-
-    return asyncio.create_task(send_forward_inner())
+    nodes = await asyncio.gather(*[create_node(msg) for msg in msgs])
+    return await send_message(
+        session=session,
+        target=target,
+        message=Reference(nodes=nodes),
+    )
 
 
 def _export_manager():
