@@ -8,9 +8,9 @@ from nonebot_plugin_session import EventSession
 from nonebot_plugin_userinfo import EventUserInfo, UserInfo
 
 from ..context import Context
-from .depends import EXECODE_ENABLED, ExtractCode
+from .depends import AllowExeCode, ExtractCode
 
-matcher = on_startswith("code", rule=EXECODE_ENABLED)
+matcher = on_startswith("code", permission=AllowExeCode)
 
 
 @matcher.handle()
@@ -22,7 +22,7 @@ async def handle_code(
 ):
     try:
         await Context.execute(bot, session, code)
-    except Exception as err:
+    except BaseException as err:
         text = f"用户{uinfo.user_name}({uinfo.user_id}) 执行代码时发生错误: {err}"
         logger.opt(exception=err).warning(text)
         await UniMessage.text(f"执行失败: {err!r}").send()
