@@ -1,12 +1,11 @@
 import contextlib
 from typing import Annotated
 
-from nonebot import get_driver
 from nonebot.adapters import Bot, Event, Message
 from nonebot.matcher import Matcher
 from nonebot.params import Depends
-from nonebot.rule import Rule
-from nonebot_plugin_alconna.uniseg import MsgTarget, UniMessage, UniMsg, reply_fetch
+from nonebot.permission import SUPERUSER, Permission
+from nonebot_plugin_alconna.uniseg import UniMessage, UniMsg, reply_fetch
 from nonebot_plugin_alconna.uniseg.segment import At, Image, Reply, Text
 from nonebot_plugin_session import EventSession
 
@@ -14,11 +13,10 @@ from ..config import config
 from ..context import Context
 
 
-def _ExeCodeEnabled() -> Rule:
-    global_config = get_driver().config
+def _AllowExeCode() -> Permission:
 
     def check_console(bot: Bot) -> bool:  # pyright: ignore[reportRedeclaration]
-        return True
+        return True  # pragma: no cover
 
     with contextlib.suppress(ImportError):
         from nonebot.adapters.console import Bot as ConsoleBot
@@ -26,22 +24,22 @@ def _ExeCodeEnabled() -> Rule:
         def check_console(bot: Bot) -> bool:
             return isinstance(bot, ConsoleBot)
 
-    async def check(bot: Bot, session: EventSession, target: MsgTarget) -> bool:
+    async def check(bot: Bot, session: EventSession) -> bool:
         # ConsoleBot 仅有标准输入, 跳过检查
         if check_console(bot):
-            return True
+            return True  # pragma: no cover
 
         # 对于 superuser 和 配置允许的用户, 在任意对话均可触发
-        if (session.id1 or "") in (global_config.superusers | config.user):
+        if (session.id1 or "") in config.user:
             return True
 
         # 当触发对话为群组时, 仅配置允许的群组可触发
-        if not target.private and target.id in config.group:
+        if session.id2 is not None and session.id2 in config.group:
             return True
 
         return False
 
-    return Rule(check)
+    return SUPERUSER | check
 
 
 def _CodeContext():
@@ -84,7 +82,7 @@ def _EventImage():
             if isinstance(reply, Message):
                 msg = await UniMessage.generate(message=reply)
                 return await event_image(msg)
-        Matcher.skip()
+        Matcher.skip()  # pragma: no cover
 
     return Depends(event_image)
 
@@ -94,7 +92,7 @@ def _EventReply():
     async def event_reply(event: Event, bot: Bot) -> Reply:
         if reply := await reply_fetch(event, bot):
             return reply
-        Matcher.skip()
+        Matcher.skip()  # pragma: no cover
 
     return Depends(event_reply)
 
@@ -102,10 +100,10 @@ def _EventReply():
 def _EventReplyMessage():
 
     async def event_reply_message(event: Event, reply: EventReply) -> Message:
-        if not (msg := reply.msg):
+        if not (msg := reply.msg):  # pragma: no cover
             Matcher.skip()
 
-        if not isinstance(msg, Message):
+        if not isinstance(msg, Message):  # pragma: no cover
             msg = type(event.get_message())(msg)
 
         return msg
@@ -113,7 +111,7 @@ def _EventReplyMessage():
     return Depends(event_reply_message)
 
 
-EXECODE_ENABLED: Rule = _ExeCodeEnabled()
+AllowExeCode: Permission = _AllowExeCode()
 CodeContext = Annotated[Context, _CodeContext()]
 ExtractCode = Annotated[str, _ExtractCode()]
 EventImage = Annotated[Image, _EventImage()]
