@@ -5,9 +5,9 @@ from nonebot import on_startswith
 from nonebot.adapters import Bot, Event
 from nonebot_plugin_alconna.uniseg import UniMessage, image_fetch
 
-from .depends import EXECODE_ENABLED, CodeContext, EventImage
+from .depends import AllowExeCode, CodeContext, EventImage
 
-matcher = on_startswith("getimg", rule=EXECODE_ENABLED)
+matcher = on_startswith("getimg", permission=AllowExeCode)
 
 
 @matcher.handle()
@@ -23,9 +23,9 @@ async def handle_getimg(
 
     try:
         img_bytes = await image_fetch(event, bot, {}, image)
-        if not isinstance(img_bytes, bytes):
+        if not isinstance(img_bytes, bytes):  # pragma: no cover
             raise ValueError(f"获取图片数据类型错误: {type(img_bytes)!r}")
-    except Exception as err:
+    except Exception as err:  # pragma: no cover
         await UniMessage(f"保存图片时出错: {err}").finish()
 
     ctx.set_gurl(image)
