@@ -1,4 +1,3 @@
-import contextlib
 from typing import Annotated
 
 from nonebot.adapters import Event
@@ -8,13 +7,8 @@ from nonebot_plugin_alconna import Alconna, Args, Match, on_alconna
 from nonebot_plugin_alconna.uniseg import At, UniMessage
 
 from ..context import Context
-from .depends import EXECODE_ENABLED
 
-matcher = on_alconna(
-    Alconna("terminate", Args["target?", At]),
-    rule=EXECODE_ENABLED,
-    permission=SUPERUSER,
-)
+matcher = on_alconna(Alconna("terminate", Args["target?", At]), permission=SUPERUSER)
 
 
 def _target(event: Event, target: Match[At]) -> str:
@@ -23,6 +17,5 @@ def _target(event: Event, target: Match[At]) -> str:
 
 @matcher.handle()
 async def handle_terminate(target: Annotated[str, Depends(_target)]):
-    with contextlib.suppress(KeyError):
-        if Context.get_context(target).cancel():
-            await UniMessage("中止").at(target).text("的执行任务").send()
+    if Context.get_context(target).cancel():
+        await UniMessage("中止").at(target).text("的执行任务").send()
